==> the-board-0.1.0.tar.bz2: the-board-0.1.0/src/js/ui/background.js <==
// gi imports
const Tb = imports.gi.Tb;

function Background(args) {
    this._init(args);
}

Background.prototype = {
    _init : function(args) {
        args = args || {};

        if ('id' in args) {
            this._id = args.id;
        } else {
            throw new Error("Background id is required");
        }

        this._content = null;

        this._createMainBox();

        if ('content' in args) {
            this._setContent(args.content);
        }
    },

    _createMainBox : function() {
        this._mainBox =
            new Tb.Box({ orientation: Tb.BoxOrientation.VERTICAL,
                         xAlign: Tb.BoxAlignment.FILL,
                         yAlign: Tb.BoxAlignment.FILL,
                         name: "background-main-box" });
    },

    _setContent : function(content) {
        if (this._content) {
            this._mainBox.remove_actor(this._content.contentActor);
        }

        this._content = content;

        if (this._content) {
            this._mainBox.append(this._content.contentActor,
                                 Tb.BoxPackFlags.EXPAND);
        }
    },

    destroy : function() {
        if (this._mainBox) {
            this._mainBox.destroy();
            delete this._mainBox;
        }
    },

    get id() {
        return this._id;
    },

    get mainBox() {
        // this getter is supposed to be used by subclasses
        // in case they want to set properties of main box.
        // We use a duplicate getter here to provide a more
        // obvious semantics when accessing main box instead
        // of the standard actor.
        return this._mainBox;
    },

    get actor() {
        return this._mainBox;
    }
}

function createBackgroundFromId(backgroundId) {
    if (!backgroundId) {
        backgroundId = 'wood';
    }

    let constructorModule = imports.ui.backgrounds[backgroundId];
    return constructorModule.create({ id: backgroundId });
}

==> the-board-0.1.1.1.tar.bz2: the-board-0.1.1.1/src/js/ui/background.js <==
// gi imports
const Tb = imports.gi.Tb;

function Background(args) {
    this._init(args);
}

Background.prototype = {
    _init : function(args) {
        args = args || {};

        if ('id' in args) {
            this._id = args.id;
        } else {
            throw new Error("Background id is required");
        }

        this._content = null;

        this._createMainBox();

        if ('content' in args) {
            this._setContent(args.content);
        }
    },

    _createMainBox : function() {
        this._mainBox =
            new Tb.Box({ orientation: Tb.BoxOrientation.VERTICAL,
                         xAlign: Tb.BoxAlignment.FILL,
                         yAlign: Tb.BoxAlignment.FILL,
                         name: "background-main-box" });
    },

    _setContent : function(content) {
        if (this._content) {
            this._mainBox.remove_actor(this._content.contentActor);
        }

        this._content = content;

        if (this._content) {
            this._mainBox.append(this._content.contentActor,
                                 Tb.BoxPackFlags.EXPAND);
        }
    },

    destroy : function() {
        if (this._mainBox) {
            this._mainBox.destroy();
            delete this._mainBox;
        }
    },

    get id() {
        return this._id;
    },

    get mainBox() {
        // this getter is supposed to be used by subclasses
        // in case they want to set properties of main box.
        // We use a duplicate getter here to provide a more
        // obvious semantics when accessing main box instead
        // of the standard actor.
        return this._mainBox;
    },

    get actor() {
        return this._mainBox;
    }
}

function createBackgroundFromId(backgroundId) {
    if (!backgroundId) {
        backgroundId = 'cork';
    }

    let constructorModule = imports.ui.backgrounds[backgroundId];
    return constructorModule.create({ id: backgroundId });
}
